@@ -7,7 +7,7 @@ use warnings;
 
 use XML::Parser;
 use Scalar::Util qw(blessed);
-use List::Util qw'first reduce pairmap pairgrep pairfirst';
+use List::Util 1.29 qw'first reduce pairmap pairgrep pairfirst';
 use Data::Dumper;
 use Log::Log4perl ':easy';
 use WWW::SFDC::Constants qw(needsMetaFile hasFolders getEnding getDiskName getName);
@@ -214,7 +214,7 @@ WWW::SFDC::Manifest - Utility functions for Salesforce Metadata API interactions
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
